from .default import prompt_models
from .default import types
from .default import contents
from .default import renderers
from .default import aspect_ratios

V4_settings = {
    "prompt_models": prompt_models,
    "types": types,
    "contents": contents,
    "renderers": renderers,
    "aspect_ratios": aspect_ratios,
}
